---
title: CLI
icon: i-carbon-terminal
description: Using the Unlighthouse CLI is the primary way to scan entire production sites.
---

Using the Unlighthouse CLI is the primary way to scan entire production sites.

## Setup

```bash
npx unlighthouse --site <your-site>
# OR pnpm dlx unlighthouse --site <your-site>
```

## Usage

Once installed globally you'll have access to Unlighthouse through the `unlighthouse` binary.

Do a the default scan.
```bash
unlighthouse --site example.com --debug
```

Run without caching, throttle the requests and do 3 samples.

```bash
unlighthouse --site example.com --debug --no-cache --throttle --samples 3
```

## Configuration

Configuring the CLI can be done either through the CLI arguments or through a config file.

See the [Configuration](#configuration) section for more details and the guides.

### CLI Options

| Options                      |                                                                                                                                                                               |
|------------------------------|-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|
| `-v, --version`              | Display version number.                                                                                                                                                       |
| `--site <url>`               | Host URL to scan.                                                                                                                                                             |
| `--root <path>`              | Define the project root.                                                                                                                                                      |
| `--config-file <path>`       | Path to config file.                                                                                                                                                          |
| `--output-path <path>`       | Path to save the contents of the client and reports to.                                                                                                                       |
| `--cache`                    | Enable the caching.                                                                                                                                                           |
| `--no-cache`                 | Disable the caching.                                                                                                                                                          |
| `--desktop`                  | Simulate device as desktop.                                                                                                                                                   |
| `--mobile`                   | Simulate device as mobile.                                                                                                                                                    |
| `--throttle`                 | Enable the throttling.                                                                                                                                                        |
| `--samples`                  | Specify the amount of samples to run.                                                                                                                                         |
| `--sitemaps`                 | Comma separated list of sitemaps to use for scanning.                                                                                                                         |
| `--urls`                     | Specify explicit relative paths as a comma-separated list.<br>e.g. `unlighthouse --site unlighthouse.dev --urls /guide,/api,/config`                                          |
| `--exclude-urls`             | Specify relative paths (string or regex) to exclude from scanning as a comma-separated list. <br>e.g. `unlighthouse --site unlighthouse.dev --exclude-urls /guide/.*,/api/.*` |
| `--include-urls`             | Specify relative paths (string or regex) to include as a comma-separated list. <br>e.g. `unlighthouse --site unlighthouse.dev --include-urls /guide/.*`                       |
| `--enable-javascript`        | When inspecting the HTML wait for the javascript to execute. Useful for SPAs.                                                                                                 |
| `--disable-javascript`       | When inspecting the HTML, don't wait for the javascript to execute.                                                                                                           |
| `--enable-i18n-pages`        | Enable scanning pages which use x-default.                                                                                                                                    |
| `--disable-i18n-pages`       | Disable scanning pages which use x-default.                                                                                                                                   |
| `--disable-dynamic-sampling` | Disable dynamic sampling of paths.                                                                                                                                            |
| `--extra-headers`           | Extra headers to send with the requests.                                                                                                                                      |
| `--default-query-params`     | Default query params to send with the requests.                                                                                                                               |
| `-d, --debug`                | Debug. Enable debugging in the logger.                                                                                                                                        |
| `-h, --help`                 | Display available CLI options                                                                                                                                                 |

### Config File

If you want to configure Unlighthouse, you can create a `unlighthouse.config.ts` file in your cwd.

```ts unlighthouse.config.ts
export default {
  site: 'example.com',
  debug: true,
  scanner: {
    device: 'desktop'
  }
}
```
